#' Vector of arbitary names for labelling designs
#'
#' Create distinctive and slightly memorable but random names.
#'
#' @param n number of names
#' @param nchar length of each name
#' @param alphabet letters (or numbers) to be used to create names
#' @param avoid names to avoid
#'
#' @export
#' @examples
#' foo <- funames(20, avoid = c("spam", "Geek"))
#' print(foo)

funames <- function(n, nchar = 4, alphabet = c(letters, LETTERS), avoid = NULL) {

    tags <- rep(NA, n)
    new <- rep(TRUE, n)

    if (!is.null(avoid)) {
        tags <- c(avoid, tags)
        new <- c(rep(FALSE, length(avoid)), new)
    }

    ## now just go around until all the names are unique   
    
    repeat {
        dup <- new & is.na(tags)
        n <- sum(dup)
        if (n == 0) break
        tmp <- sample(alphabet, n * nchar, replace = TRUE)
        dim(tmp) <- c(n, nchar)
        tmp <- apply(tmp, 1, paste, collapse = "")
        tags[dup] <- tmp
        tags[duplicated(tags)] <- NA # has no effect if no duplicates
    }
    
    tags[new]
}
