#' Euclidean distances between the rows of two matrices
#'
#' This is a variant on \code{\link{dist}}.  It only does Euclidean
#' distance, but it can take two sets of points (not just one).  It
#' always returns a distance matrix.
#'
#' @param X Matrix of points (one point per row)
#' @param Y Another matrix, same number of columns as \code{X}
#'
#' @seealso \code{\link{dist}}
#' @return A matrix with \code{nx} rows and \code{ny} columns.
#' @export
#' @examples
#' foo <- matrix(rnorm(11*5), 11, 5)
#' mydist(foo)
#' mydist(foo[1:7, ], foo[8:11, ])

mydist <- function(X, Y = NULL) {

    stopifnot(is.matrix(X))
    if (is.null(Y)) return(as.matrix(dist(X)))

    ## OK, have to do this the hard way!
    
    stopifnot(is.matrix(Y), ncol(X) == ncol(Y))
    nx <- nrow(X); rx <- rownames(X)
    ny <- nrow(Y); ry <- rownames(Y)
    X <- X[rep(1L:nx, ny), , drop=FALSE]
    Y <- Y[rep(1L:ny, each = nx), , drop = FALSE]
    robj <- sqrt(rowSums((X - Y)^2))
    dim(robj) <- c(nx, ny)
    if (!is.null(rx)) rownames(robj) <- rx
    if (!is.null(ry)) colnames(robj) <- ry
    robj
}
    
