\name{boxdesign}
\alias{[.boxdesign}
\alias{boxdesign}
\alias{extend.boxdesign}
\alias{head.boxdesign}
\alias{rbind.boxdesign}
\alias{shrink.boxdesign}
\alias{tail.boxdesign}
\title{Create and modify a rectangular design}
\usage{
boxdesign(n, param = list(), log. = NULL, U = maximin(n, p))

extend.boxdesign(X, n, update = list(), ...)

shrink.boxdesign(X, n, ...)

\method{[}{boxdesign}(x, ...)

rbind.boxdesign(x, y)

\method{head}{boxdesign}(x, n = 6L, ...)

\method{tail}{boxdesign}(x, n = 6L, ...)
}
\arguments{
  \item{n}{size of design; new points to add, points to
  retain, points to show}

  \item{param}{named list of parameter lower and upper
  bounds}

  \item{log.}{indices or names of parameters to have their
  points on a log scale}

  \item{U}{underlying set of points on \eqn{[0, 1]^p}}

  \item{X}{object of class \code{boxdesign}}

  \item{update}{list of the parameter ranges to be updated}

  \item{...}{additional arguments to \code{extend.lhcube}
  or \code{shrink.lhcube}}

  \item{x,y}{arguments to \code{[} operator or
  \code{rbind}}
}
\value{
A design matrix with named rows and columns of class
\code{boxdesign}.  Has a \code{param} argument with the
ranges, and possibly a \code{log.} argument.
}
\description{
Rectangular ('box') design based on lower and upper limits,
with the option to distribute the points logarithmically
rather than linearly (for a positive lower limit).

\code{extend.boxdesign} generates an additional design
which is space-filling with respect to the first.
\code{shrink.boxdesign} removes rows from a given design.

There is an extraction method (\code{[}) for
\code{boxdesign} objects, and an \code{rbind} method.  Also
\code{head} and \code{tail} methods, which do not preserve
the \code{boxdesign} class (see Details).
}
\details{
In \code{boxdesign}, the argument \code{U} would typically
not be specified, as it is used mainly by
\code{extend.boxdesign}.  But it can be specified to
override the default arguments in \code{maximin}.

\code{extend.boxdesign} is for adding rows.  The
\code{update} argument is for adjusting the ranges of
parameters, and only needs to be specified for parameters
whose ranges change. \code{shrink.boxdesign} is for
removing rows.  An internal function \code{tozeroone} is
used to rescale \code{X} in both cases.

For a new object of class \code{boxdesign} comprising the
first 10 rows, use \code{X[1:10, ]}.  But for a matrix of
the first 10 rows, eg as a quick summary, use \code{head(X,
10)}.
}
\examples{
X <- boxdesign(10, list(foo = c(1, 2), bar = c(3, 10)))
Y <- boxdesign(10, list(foo = c(1, 2), bar = c(3, 10)), log = "bar")
## now extend and combine this design

Z <- extend.boxdesign(Y, n = 5) # just 5 new rows

## change some limits

Z <- extend.boxdesign(Y, n = 5, update = list(bar = c(7, 11)))
Z <- rbind(Y, Z) # add them on to Y
## use the extraction operator and rbind

keep <- Z[, 1] < 1.5
Z[keep, ]
Z[keep, "bar"]
rbind(Z[1:5, ], Z[8:10, ])

## example of shrinking a design

Z <- boxdesign(100, param = list(foo = c(0, 1), bar = c(0, 1)))
keep <- Z[, "foo"] <= Z[, "bar"]
Z <- shrink.boxdesign(Z[keep, ], 20)

## head (and tail) just return matrices

head(Z, 10)
}
\seealso{
\code{\link{lhcube}} for space-filling designs on the unit
cube.
}
\concept{
Experimental design
}
\keyword{utilities}

