\name{lhc}
\alias{extend.lhcube}
\alias{lhc}
\alias{lhcube}
\alias{maximin}
\alias{shrink.lhcube}
\title{Create an n by p (maximin) Latin Hypercube design.}
\usage{
lhcube(n, p, noisy = TRUE)

maximin(..., nrep = 100)

extend.lhcube(U, n, noisy = TRUE, nrep = 100)

shrink.lhcube(U, n, type = c("row", "indices"), nrep = 100)
}
\arguments{
  \item{n}{number of rows in the design}

  \item{p}{number of columns in the design}

  \item{noisy}{logical, perturb points?}

  \item{...}{Arguments to \code{lhcube}}

  \item{nrep}{Number of of replications}

  \item{U}{Latin hypercube}

  \item{type}{Type of object to return, either the selected
  rows of \code{U} or the indices of the selected rows in
  \code{U}}
}
\value{
A design matrix on \eqn{[0, 1]^p}.
}
\description{
A Latin Hypercube (LHC) is a random space-filling design
with equally-spaced margins on the interval (0, 1).  It is
often helpful to perturb the points (\code{noisy = TRUE})
to introduce some small-scale variability in the margins.
Bad LHC designs are possible; one approach to avoid this is
to select a good design from many candidates, such as a
\code{maximin} LHC.

Functions \code{extend.lhcube} and \code{shrink.lhcube} use
the maximin criterion to choose good extensions or subsets.
In both cases, \code{n} indicates the number of rows in the
new design.
}
\section{Warning}{
  Neither \code{extend.lhcube} nor \code{shrink.lhcube}
  will provide a warning if \code{U} is not contained in
  \eqn{[0, 1]^p}, as it is sometimes convenient to use a
  larger range (eg in \code{extend.boxdesign}).
}

\section{Helpful tips}{
  Each row gets a unique name.  Pass this name along with
  the row values into your code, as an additional input.
  Make sure it gets written into the output as well.  That
  way there can be no confusion about which rows in the
  design are associated with which outputs.

  To map the columns of the output to other distributions,
  use the Probability Integral Transform; see the Examples.
}
\examples{
foo <- lhcube(10, 3)
print(foo)

## to map a column to a different range use the Probability
## Integral Transform

foo[, 2] <- qunif(foo[, 2], min = 10, max = 70)
foo[, 3] <- qnorm(foo[, 3], mean = 5.5, sd = 2.1)
print(foo)
## maximin LHCs

lhc1 <- lhcube(21, 2, noisy = FALSE)
lhc2 <- maximin(21, 2, noisy = FALSE)
plot(lhc1, type = "p", pch = 20, col = 1)
points(lhc2, pch = 20, col = 2)
## extend LHCs using maximin

lhc1 <- lhcube(21, 2)
lhc2 <- extend.lhcube(lhc1, n = 17)
plot(lhc1, type = "p", pch = 20, col = 1)
points(lhc2, pch = 20, col = 2)
## drop rows from LHC using maximin

lhc1 <- lhcube(21, 2)
lhc2 <- shrink.lhcube(lhc1, n = 10)
plot(lhc1, type = "p", pch = 20, col = 1)
points(lhc2, pch = 1, cex = 1.25, col = 2)
}
\seealso{
The functions in the \code{DiceDesign} package.
\code{\link{boxdesign}} for creating simple rectangular
designs.
}
\concept{
Experimental design
}
\keyword{utilities}

