\name{ref}
\alias{ref}
\title{Row echelon form}
\usage{
ref(X, tol = 1e-08)
}
\arguments{
  \item{X}{matrix}

  \item{tol}{tolerance for testing equality with zero}
}
\value{
A matrix the same size as \code{X}, but with zeros below
the diagonal, and on the diagonal as well if \code{X} does
not have full column rank.
}
\description{
Put m by n matrix \code{X} into row echelon form.
}
\details{
See Strang (2006, sec 2.2) for details about row echelon
form.  \code{ref} implements a generalisation of the outer
product Gaussian elimination algorithm of Golub and Van
Loan (1996, Algorithm 3.2.1).
}
\examples{
## test out a few obvious cases

pivot <- function(X) {
  X <- X[!apply(X == 0, 1, all), , drop=FALSE]
  apply(X != 0, 1, which.max)
}

X <- matrix(rnorm(18), 6, 3)
Y <- ref(X)
print(Y); print(pivot(Y)) # == c(1, 2, 3)
ref(t(X))
print(Y); print(pivot(Y)) # == c(1, 2, 3)
X <- cbind(X[, 1:2], 3 * X[, 1] - 4 * X[, 2], X[, 3])
Y <- ref(X)
print(Y); print(pivot(Y)) # == c(1, 2, 4)
Y <- ref(X[1:3, ])
print(Y); print(pivot(Y)) # == c(1, 2, 4)
}
\references{
G.H. Golub and C.F. Van Loan, 1996, Matrix Computations,
3rd ed, The John Hopkins University Press, Baltimore, MD,
USA.

G. Strang, 2006, Linear Algebra and its Applications, 4th
ed, Thomson Brooks/Cole Belmont CA, USA.
}
\seealso{
This code is used in \code{\link{prvar}}.
}

